@@ -54,6 +54,13 @@ let create_ssh ?bandwidth ?cor ?(retry=true)
   if retry then
     Nbdkit.add_filter_if_available cmd "retry";
 
+  (* Add the count filter if available, to report bytes read.
+   * Since it writes a debug message, only do this if verbose.
+   * This should be close to the plugin so we're reporting what
+   * is read over the wire.
+   *)
+  if verbose () then Nbdkit.add_filter_if_available cmd "count";
+
   (* IMPORTANT! Add the COW filter.  It must be furthest away
    * except for the rate filter.
    *)
